@@ -1,12 +1,13 @@
 from pydantic import BaseModel
 from typing import Optional, List
 from enum import IntEnum
+from import_models import ProductGroupJsonDTO, FADNProductJsonDTO, PolicyJsonDTO
 
-class OrganicProductionTypeEnum(IntEnum):
-    CONVENTIONAL = 0
-    ORGANIC = 1
-    UNDETERMINED = 2
-
+class OrganicProductionType(IntEnum):
+    Conventional = 0
+    Organic = 1
+    Undetermined = 2
+    
 class AgriculturalProduction(BaseModel):
     id: Optional[int] = None
     farmId: int
@@ -17,7 +18,7 @@ class AgriculturalProduction(BaseModel):
     cropProduction: float
     irrigatedArea: float
     cultivatedArea: float
-    organicProductionType: OrganicProductionTypeEnum
+    organicProductionType: OrganicProductionType
     variableCosts: float
     landValue: float
     sellingPrice: float
@@ -32,7 +33,7 @@ class AgriculturalProductionDTO(BaseModel):
     cropProduction: float
     irrigatedArea: float
     cultivatedArea: float
-    organicProductionType: OrganicProductionTypeEnum
+    organicProductionType: OrganicProductionType
     variableCosts: float
     landValue: float
     sellingPrice: float
@@ -79,9 +80,9 @@ class Farm(BaseModel):
     lat: int
     long: int
     altitude: int
-    regionLevel1: int
+    regionLevel1: str
     regionLevel1Name: str
-    regionLevel2: int
+    regionLevel2: str
     regionLevel2Name: str
     regionLevel3: int
     regionLevel3Name: str
@@ -97,8 +98,8 @@ class ProductGroup(BaseModel):
     productType: int
     originalNameDatasource: str
     productsIncludedInOriginalDataset: str
-    arable: bool
-    organic: OrganicProductionTypeEnum
+    organic: OrganicProductionType
+    modelSpecificCategories: List[str]
     
 class FADNProductRelation(BaseModel):
     id: Optional[int] = None
@@ -180,14 +181,19 @@ class ValueToLPDTO(BaseModel):
     m_0: float
 
 class CropDataDTO(BaseModel):
-    cropProductiveArea: int
+    cropProductiveArea: float
     cropVariableCosts: float
-    cropProduction: float
+    quantitySold: float
     cropSellingPrice: float
     coupledSubsidy: float
     uaa: float
-    rebreeding_cows: float
-    dairy_cows: float
+    rebreedingCows: float
+    dairyCows: float
+
+class DecoupledSubsidiesDTO(BaseModel):
+    pGreen: float
+    pBasic: float
+    pPension: float
 
 class ValueFromSPDTO(BaseModel):
     farmId: int
@@ -198,6 +204,7 @@ class ValueFromSPDTO(BaseModel):
     crops: dict[str,CropDataDTO]
     totalVariableCosts: float
     rentBalanceArea: float
+    decoupledSubsidies: DecoupledSubsidiesDTO
 
 class LivestockDTO(BaseModel):
     numberOfAnimals: float
@@ -207,9 +214,7 @@ class LivestockDTO(BaseModel):
     milkSellingPrice: float
     variableCosts: float
 
-class DecoupledSubsidiesDTO(BaseModel):
-    pGreen: float
-    pBasic: float
+
 
 class HolderInfoDTO(BaseModel):
     holderAge: int
@@ -225,8 +230,8 @@ class AltitudeEnum(IntEnum):
 class ValueToSPDTO(BaseModel):
     farmCode: int
     holderInfo: Optional[HolderInfoDTO] = None
-    cod_RAGR: int
-    cod_RAGR2: int
+    cod_RAGR: str
+    cod_RAGR2: str
     cod_RAGR3: int
     technicalEconomicOrientation: int
     altitude: AltitudeEnum
@@ -237,7 +242,7 @@ class ValueToSPDTO(BaseModel):
 
 class DataToSPDTO(BaseModel):
     values: List[ValueToSPDTO]
-    arableProductGroupsNames: List[str]
+    productGroups: List[ProductGroupJsonDTO]
     coupledSubsidiesProductGroupsDict: dict[str,str]
 
 class IntermediateValueFromLP(BaseModel):
