@@ -1,11 +1,11 @@
-from agricore_sp_models.agricore_sp_models import OrganicProductionTypeEnum
+from agricore_sp_models.agricore_sp_models import OrganicProductionType
 from pydantic import BaseModel, Field
 from typing import List
 
 class AgriculturalProductionJsonDTO(BaseModel):
     yearNumber: int
     productName: str 
-    organicProductionType: str 
+    organicProductionType: OrganicProductionType
     cultivatedArea: float
     irrigatedArea: float 
     cropProduction: float
@@ -96,11 +96,11 @@ class FarmJsonDTO(BaseModel):
     lat: int
     long: int
     altitude: str = ""
-    regionLevel1: int
+    regionLevel1: str
     regionLevel1Name: str = ""
-    regionLevel2: int
+    regionLevel2: str
     regionLevel2Name: str = ""
-    regionLevel3: int
+    regionLevel3: str
     regionLevel3Name: str = ""
     technicalEconomicOrientation: int
     agriculturalProductions: List[AgriculturalProductionJsonDTO]
@@ -126,8 +126,8 @@ class ProductGroupJsonDTO(BaseModel):
     productType: str
     originalNameDatasource: str
     productsIncludedInOriginalDataset: str
-    arable: bool
-    organic: OrganicProductionTypeEnum
+    modelSpecificCategories: List[str]
+    organic: OrganicProductionType
     fadnProducts: List[FADNProductJsonDTO]
     policies: List[PolicyJsonDTO]
     
